==> 1.5.2.tar.xz: 1.5.2/search/enumvalues_2.js <==
var searchData=
[
  ['camera_5fauto_5fexposure_0',['CAMERA_AUTO_EXPOSURE',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423aba38501dbc9b4a9a9f921d0a40d8c1fb',1,'rm']]],
  ['camera_5fauto_5fwb_1',['CAMERA_AUTO_WB',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423a4f96a87ba77f6cfdca97b7dfcbac9972',1,'rm']]],
  ['camera_5fcontrast_2',['CAMERA_CONTRAST',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423ac1a2a996692cb0b6da234990a9f132d9',1,'rm']]],
  ['camera_5fexposure_3',['CAMERA_EXPOSURE',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423a5b0ea66f2c7029d10ea3b4505fcc784c',1,'rm']]],
  ['camera_5fframe_5fheight_4',['CAMERA_FRAME_HEIGHT',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423a94adf1643237aa40526fa70a113e2634',1,'rm']]],
  ['camera_5fframe_5fwidth_5',['CAMERA_FRAME_WIDTH',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423a285d496bcbd08079b0c316b6d7e7ce22',1,'rm']]],
  ['camera_5fgain_6',['CAMERA_GAIN',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423aee4e28daf641d7d80989a0240b1bad16',1,'rm']]],
  ['camera_5fgamma_7',['CAMERA_GAMMA',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423ace4056201e197b9542f81baebe04d103',1,'rm']]],
  ['camera_5fmanual_5fexposure_8',['CAMERA_MANUAL_EXPOSURE',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423a59e64c9447cf3096c426587cc1bd6e13',1,'rm']]],
  ['camera_5fmanual_5fwb_9',['CAMERA_MANUAL_WB',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423ae64a4a686a53a8c737d1ca10af38e96c',1,'rm']]],
  ['camera_5fonce_5fexposure_10',['CAMERA_ONCE_EXPOSURE',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423a8b69486bb4913dd09814d341a399f568',1,'rm']]],
  ['camera_5fonce_5fwb_11',['CAMERA_ONCE_WB',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423aad4505f28b41f355ff821263345544aa',1,'rm']]],
  ['camera_5fsaturation_12',['CAMERA_SATURATION',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423a4e59d0a3cc5a29a91906432a818bc1bc',1,'rm']]],
  ['camera_5fsharpness_13',['CAMERA_SHARPNESS',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423ae4750fa886f1876d153a68c5bc3b2e2f',1,'rm']]],
  ['camera_5ftrigger_5fcount_14',['CAMERA_TRIGGER_COUNT',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423afd014bac1dc13348619b6107d4185c71',1,'rm']]],
  ['camera_5ftrigger_5fdelay_15',['CAMERA_TRIGGER_DELAY',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423af4d09eb79373a2afa208c9ffb386d898',1,'rm']]],
  ['camera_5ftrigger_5fperiod_16',['CAMERA_TRIGGER_PERIOD',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423adbef478f5e47ac1462a3abe745e8ad83',1,'rm']]],
  ['camera_5ftrigger_5fsoft_17',['CAMERA_TRIGGER_SOFT',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423a12208efc7911e8dfb4b9fb46aa6bb313',1,'rm']]],
  ['camera_5fwb_5fbgain_18',['CAMERA_WB_BGAIN',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423a07d8c840fa3c4cce61481159b7c3247e',1,'rm']]],
  ['camera_5fwb_5fggain_19',['CAMERA_WB_GGAIN',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423a34a84085560fe527d704d46608dddc58',1,'rm']]],
  ['camera_5fwb_5frgain_20',['CAMERA_WB_RGAIN',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423aebabd6b90c4ce8da92954bcfdb26b801',1,'rm']]],
  ['central_21',['Central',['../d8/db4/group__core__optimal.html#gga329a52f13003e4dd7914217ed7f3f5eda4a8c79ddddd6109289084e80aa41cdf2',1,'rm']]],
  ['char_5fa_22',['CHAR_A',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6ad0f71a7556f684105699da34f4fa3fc1',1,'rm']]],
  ['char_5fb_23',['CHAR_B',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6a7fa61ff7713023af30a4334d56871daa',1,'rm']]],
  ['char_5fc_24',['CHAR_C',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6adfa0cec991013ea275a93447d5733426',1,'rm']]],
  ['char_5fd_25',['CHAR_D',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6a48e6635135aa1ce46690d788d5bb9dfc',1,'rm']]],
  ['char_5fe_26',['CHAR_E',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6a5eafdd69dab53fffe4f2574507b01b37',1,'rm']]],
  ['char_5ff_27',['CHAR_F',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6a2abce8311e1b8daa0a5ab103beb3bcfe',1,'rm']]],
  ['char_5fg_28',['CHAR_G',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6a08303312b79925efc4a3752f0dd1100c',1,'rm']]],
  ['char_5fh_29',['CHAR_H',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6a2fe742ce08ee538caa470dc86c07630e',1,'rm']]],
  ['char_5fi_30',['CHAR_I',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6a343e118d44055eb1dc0a7a5a57cc49a0',1,'rm']]],
  ['char_5fj_31',['CHAR_J',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6a570db920ca903f98b44817e576c3d44f',1,'rm']]],
  ['char_5fk_32',['CHAR_K',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6a6fd40774c75cabfae885de563a70a6a4',1,'rm']]],
  ['char_5fl_33',['CHAR_L',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6ab1a90eef3b4ac85b89daf6da2465a7ee',1,'rm']]],
  ['char_5fm_34',['CHAR_M',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6a494bff9388fb87fbba82f13a36134ac5',1,'rm']]],
  ['char_5fn_35',['CHAR_N',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6a5c52906e06a43d69e1b785b008877fb5',1,'rm']]],
  ['char_5fo_36',['CHAR_O',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6a8291c3c6fc07dc5dabd6824b028887c7',1,'rm']]],
  ['char_5fp_37',['CHAR_P',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6a64c6d9ba79f44d9c411deb39e96aaabd',1,'rm']]],
  ['char_5fq_38',['CHAR_Q',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6abc1dbeffb36a9635154216a3e7cf4b4d',1,'rm']]],
  ['char_5fr_39',['CHAR_R',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6ad6469edc76b11d43c369a50467dedfcc',1,'rm']]],
  ['char_5fs_40',['CHAR_S',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6a7e7271634c0f4bd1c9522b353d56e881',1,'rm']]],
  ['char_5ft_41',['CHAR_T',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6ad5ec54d89ae843661bc7310043a9c3be',1,'rm']]],
  ['char_5fu_42',['CHAR_U',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6ab6459fa9913f3575b512496e06772670',1,'rm']]],
  ['char_5fv_43',['CHAR_V',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6a8d81bc4671c93b680b555b671d2fe66f',1,'rm']]],
  ['char_5fw_44',['CHAR_W',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6aed64411dc7778c1049346942a413a8d7',1,'rm']]],
  ['char_5fx_45',['CHAR_X',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6a992f9bd39c5cf6d07c49901f3ed5260d',1,'rm']]],
  ['char_5fy_46',['CHAR_Y',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6a2786cb9725c2bae2b63034054608003b',1,'rm']]],
  ['char_5fz_47',['CHAR_Z',['../d6/d59/group__types.html#gga53b2ed651ce89a5884af7310fb1a24d6a27d4977c39c33451a68cfaa8bb5222ea',1,'rm']]],
  ['chn0_48',['Chn0',['../dc/d90/group__camera.html#ggafd1e51b9b1633d344461f1cb73a26b7aa4c8f067bdd364e561fd1a5b766fb30da',1,'rm']]],
  ['chn1_49',['Chn1',['../dc/d90/group__camera.html#ggafd1e51b9b1633d344461f1cb73a26b7aa965c0cc3993772fa0890e4f26c953467',1,'rm']]],
  ['chn2_50',['Chn2',['../dc/d90/group__camera.html#ggafd1e51b9b1633d344461f1cb73a26b7aac1d24a7c11cfbd7898dd36f172f996b6',1,'rm']]],
  ['chn3_51',['Chn3',['../dc/d90/group__camera.html#ggafd1e51b9b1633d344461f1cb73a26b7aabbb9ea5d9d7ad6cf024bb0a8c9210aa6',1,'rm']]],
  ['conjgrad_52',['ConjGrad',['../d8/db4/group__core__optimal.html#ggaf5b1502951081346a5bc6f03694fe73ca4665d7d50e9615f1531abbdcc001e0ce',1,'rm']]],
  ['continuous_53',['Continuous',['../dc/d90/group__camera.html#gga90ca2fddbb5f19ea4dc6f862157be49da535863a82f163709557e59e2eb8139a7',1,'rm']]],
  ['cpu_54',['CPU',['../dc/d73/group__ml__ort.html#ggaa3efd1984486e48014bbcfc54e432e84a2b55387dd066c5bac646ac61543d152d',1,'rm']]],
  ['cuda_55',['CUDA',['../dc/d73/group__ml__ort.html#ggaa3efd1984486e48014bbcfc54e432e84aa33b7755e5f9b504d2d038eaca4ff28d',1,'rm']]]
];

==> 2.3.0.tar.xz: 2.3.0/search/enumvalues_2.js <==
var searchData=
[
  ['camera_5fauto_5fexposure_0',['CAMERA_AUTO_EXPOSURE',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423aba38501dbc9b4a9a9f921d0a40d8c1fb',1,'rm']]],
  ['camera_5fauto_5fwb_1',['CAMERA_AUTO_WB',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423a4f96a87ba77f6cfdca97b7dfcbac9972',1,'rm']]],
  ['camera_5fcontrast_2',['CAMERA_CONTRAST',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423ac1a2a996692cb0b6da234990a9f132d9',1,'rm']]],
  ['camera_5fexposure_3',['CAMERA_EXPOSURE',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423a5b0ea66f2c7029d10ea3b4505fcc784c',1,'rm']]],
  ['camera_5fframe_5fheight_4',['CAMERA_FRAME_HEIGHT',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423a94adf1643237aa40526fa70a113e2634',1,'rm']]],
  ['camera_5fframe_5fwidth_5',['CAMERA_FRAME_WIDTH',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423a285d496bcbd08079b0c316b6d7e7ce22',1,'rm']]],
  ['camera_5fgain_6',['CAMERA_GAIN',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423aee4e28daf641d7d80989a0240b1bad16',1,'rm']]],
  ['camera_5fgamma_7',['CAMERA_GAMMA',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423ace4056201e197b9542f81baebe04d103',1,'rm']]],
  ['camera_5fmanual_5fexposure_8',['CAMERA_MANUAL_EXPOSURE',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423a59e64c9447cf3096c426587cc1bd6e13',1,'rm']]],
  ['camera_5fmanual_5fwb_9',['CAMERA_MANUAL_WB',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423ae64a4a686a53a8c737d1ca10af38e96c',1,'rm']]],
  ['camera_5fonce_5fexposure_10',['CAMERA_ONCE_EXPOSURE',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423a8b69486bb4913dd09814d341a399f568',1,'rm']]],
  ['camera_5fonce_5fwb_11',['CAMERA_ONCE_WB',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423aad4505f28b41f355ff821263345544aa',1,'rm']]],
  ['camera_5fsaturation_12',['CAMERA_SATURATION',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423a4e59d0a3cc5a29a91906432a818bc1bc',1,'rm']]],
  ['camera_5fsharpness_13',['CAMERA_SHARPNESS',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423ae4750fa886f1876d153a68c5bc3b2e2f',1,'rm']]],
  ['camera_5ftrigger_5fcount_14',['CAMERA_TRIGGER_COUNT',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423afd014bac1dc13348619b6107d4185c71',1,'rm']]],
  ['camera_5ftrigger_5fdelay_15',['CAMERA_TRIGGER_DELAY',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423af4d09eb79373a2afa208c9ffb386d898',1,'rm']]],
  ['camera_5ftrigger_5fperiod_16',['CAMERA_TRIGGER_PERIOD',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423adbef478f5e47ac1462a3abe745e8ad83',1,'rm']]],
  ['camera_5ftrigger_5fsoft_17',['CAMERA_TRIGGER_SOFT',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423a12208efc7911e8dfb4b9fb46aa6bb313',1,'rm']]],
  ['camera_5fwb_5fbgain_18',['CAMERA_WB_BGAIN',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423a07d8c840fa3c4cce61481159b7c3247e',1,'rm']]],
  ['camera_5fwb_5fggain_19',['CAMERA_WB_GGAIN',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423a34a84085560fe527d704d46608dddc58',1,'rm']]],
  ['camera_5fwb_5frgain_20',['CAMERA_WB_RGAIN',['../dc/d90/group__camera.html#gga3dabb1d304a05608ec415f8f6c289423aebabd6b90c4ce8da92954bcfdb26b801',1,'rm']]],
  ['cauchy_21',['Cauchy',['../d2/d62/group__algorithm__optimal.html#ggafda9bd41e45a035a7b6c5e1bb740de15a2ee21c55474972b3e65b31a6b0b57dc8',1,'rm']]],
  ['central_22',['Central',['../d2/d62/group__algorithm__optimal.html#gga329a52f13003e4dd7914217ed7f3f5eda4a8c79ddddd6109289084e80aa41cdf2',1,'rm']]],
  ['chn0_23',['Chn0',['../dc/d90/group__camera.html#ggafd1e51b9b1633d344461f1cb73a26b7aa4c8f067bdd364e561fd1a5b766fb30da',1,'rm']]],
  ['chn1_24',['Chn1',['../dc/d90/group__camera.html#ggafd1e51b9b1633d344461f1cb73a26b7aa965c0cc3993772fa0890e4f26c953467',1,'rm']]],
  ['chn2_25',['Chn2',['../dc/d90/group__camera.html#ggafd1e51b9b1633d344461f1cb73a26b7aac1d24a7c11cfbd7898dd36f172f996b6',1,'rm']]],
  ['chn3_26',['Chn3',['../dc/d90/group__camera.html#ggafd1e51b9b1633d344461f1cb73a26b7aabbb9ea5d9d7ad6cf024bb0a8c9210aa6',1,'rm']]],
  ['circle_27',['Circle',['../db/dc8/group__anchor.html#gga8fef01d184cf75eca3985168901fd5b7a30954d90085f6eaaf5817917fc5fecb3',1,'rm']]],
  ['conjgrad_28',['ConjGrad',['../d2/d62/group__algorithm__optimal.html#ggaf5b1502951081346a5bc6f03694fe73ca4665d7d50e9615f1531abbdcc001e0ce',1,'rm']]],
  ['connect_29',['Connect',['../d6/dd4/group__io__net.html#ggae6fd8f56e227d1b8dd738a46939dd2fca49ab28040dfa07f53544970c6d147e1e',1,'rm']]],
  ['continuous_30',['Continuous',['../dc/d90/group__camera.html#gga90ca2fddbb5f19ea4dc6f862157be49da535863a82f163709557e59e2eb8139a7',1,'rm']]],
  ['cpu_31',['CPU',['../dc/d73/group__ml__ort.html#ggaa3efd1984486e48014bbcfc54e432e84a2b55387dd066c5bac646ac61543d152d',1,'rm']]],
  ['cross_32',['Cross',['../db/dc8/group__anchor.html#gga8fef01d184cf75eca3985168901fd5b7ae76b449b9fc8536af7557ffa6321d269',1,'rm']]],
  ['cuda_33',['CUDA',['../dc/d73/group__ml__ort.html#ggaa3efd1984486e48014bbcfc54e432e84aa33b7755e5f9b504d2d038eaca4ff28d',1,'rm']]]
];
